<?php $TRANSLATIONS = array(
"Music" => "Музика",
"songs" => "нумере",
"albums" => "албуми",
"Add to playlist" => "Додај на листу",
"Add album to playlist" => "Додај албум на листу",
"Play" => "Пусти",
"Pause" => "Паузирај",
"Previous" => "Претходна",
"Next" => "Следећа",
"Mute" => "Искључи звук",
"Unmute" => "Укључи звук",
"Rescan Collection" => "Поново претражи збирку",
"Artist" => "Извођач",
"Album" => "Албум",
"Title" => "Наслов"
);
